==> haskell-pandoc-lua-engine-0.2.1.2-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-FNTia9xrWAiEbt8EJyRdnr
key:                  pandoc-lua-engine-0.2.1.2-FNTia9xrWAiEbt8EJyRdnr
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  1540e7e1769374b583271693ecddb5ab
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-FNTia9xrWAiEbt8EJyRdnr
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-LsWv4TtWmiVDJAUQ0ooXGa
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doclayout-0.4.0.1-9g29y644Csz8IthvvzHtSq
    doctemplates-0.11-Dpohx8aMJDGLtGnfT9sqrP exceptions-0.10.4
    hslua-2.3.0-Le4uRNG04u6Cl04H268Sso
    hslua-module-doclayout-1.1.0-BY0relJo2xS5htbtJBYNI4
    hslua-module-path-1.1.0-4Mz8pcYNlSY5MVuFgbOFDX
    hslua-module-system-1.1.0.1-D1Dg62owNiW2pIQFCBgHR6
    hslua-module-text-1.1.0.1-LA0vSgu65336o5wuFTQ2KL
    hslua-module-version-1.1.0-HNyDmuqyVdg1OhlDrIqNWl
    hslua-module-zip-1.1.1-5tASVo62Ok8JixWS5OSa5j
    hslua-repl-0.1.2-4Q8qfySZIKA3sf7fZDbIHS
    lpeg-1.0.4-1ZsBBiYP1Gy7W3Dr4eW4DB mtl-2.2.2
    pandoc-3.1.8-3ccdAF2j3ToDhVpivODqEj
    pandoc-lua-marshal-0.2.3-HsjYgJEgSJ32AAE8IB3JgK
    pandoc-types-1.23.1-6iBWeANyBCx4yQukPF7cP1 parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-engine-0.2.1.2-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-5oqt30jHiCS34ah9VNnzBT
key:                  pandoc-lua-engine-0.2.1.2-5oqt30jHiCS34ah9VNnzBT
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  1310bf411cbee8629d918684f550bb14
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-5oqt30jHiCS34ah9VNnzBT
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-K5Kz3OFWNuqIQAWGDRs9Ud
    containers-0.6.5.1 data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    doclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
    doctemplates-0.11-C27zRlWEVxT91PVtji9RxN exceptions-0.10.4
    hslua-2.3.0-EQeElTppdO0EglsvALVWWe
    hslua-module-doclayout-1.1.0-2JgzsB8V0OSgQJSXW7vrM
    hslua-module-path-1.1.0-7O5wOUXVtcFBZbHbkwy9Aq
    hslua-module-system-1.1.0.1-L7dsFEeefJH8gz5ZXh3vFX
    hslua-module-text-1.1.0.1-5Kn0Ue1eTL25OxpZBoxoei
    hslua-module-version-1.1.1-EObnYpIhwx82HBaQxwcESz
    hslua-module-zip-1.1.1-GBcIi0EFmF17mN2Ks3EN0C
    hslua-repl-0.1.2-C9lIZj2e7E6A6v7J5xFuHK
    lpeg-1.0.4-APa1iqOP7MzKYkRd1E3mM5 mtl-2.2.2
    pandoc-3.1.11-2h8qSqwWhzsFX4oHPfhgYO
    pandoc-lua-marshal-0.2.6-8NA6OCjPpAKI1SOd8O5WUN
    pandoc-types-1.23.1-9zMZjeuwTZD9DvwIlvEps5 parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
